@@ -10,7 +10,7 @@ def main():
     cube.transform.localPosition = Vector3(-5, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((255, 0, 0))
+    renderer.mat = Material(Color(255, 0, 0))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(-6, -1, -1), Vector3(-4, 1, 1))
     rb = cube.AddComponent(Rigidbody)
@@ -24,7 +24,7 @@ def main():
     cube.transform.localPosition = Vector3(5, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((0, 0, 255))
+    renderer.mat = Material(Color(0, 0, 255))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(4, -1, -1), Vector3(6, 1, 1))
     rb = cube.AddComponent(Rigidbody)
@@ -37,7 +37,7 @@ def main():
     cube.transform.localPosition = Vector3(0, 0, -6)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((0, 255, 0))
+    renderer.mat = Material(Color(0, 255, 0))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(-1, -1, -7), Vector3(1, 1, -5))
     rb = cube.AddComponent(Rigidbody)
